API docs for “spamfighter.interfaces.IAttribute”

# Class s.i.IAttribute(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Атрибуты характеризуют отправителя и получателя сообщений, они могут нести разную информацию.

Атрибут является частью сообщения (`IMessage`), тип атрибута (`IAttributeDomain`) - его свойством.

Method | domain | Получить домен атрибута.
Method | value | Получить значение атрибута.
Method | serialize | Получить сериализованное значение атрибута.

def domain(): (source)
Получить домен атрибута.

Returns | домен атрибута (type: `IAttributeDomain` )

def value(): (source)
Получить значение атрибута.

Returns | значение атрибута

def serialize(): (source)
Получить сериализованное значение атрибута.

Returns | сериализованное значение атрибута